
/// inotify cron basic definition file
/**
 * \file incron.h
 *
 * inotify cron system
 *
 * Copyright (C) 2006, 2007, 2008, 2009 Lukas Jelinek, <lukas@aiken.cz>
 * Copyright (C) 2014, 2015 Andreas Altair Redmer, <altair.ibn.la.ahad.sy@gmail.com>
 *
 * This program is free software; you can use it, redistribute
 * it and/or modify it under the terms of the GNU General Public
 * License, version 2 (see LICENSE-GPL).
 *
 */


#ifndef _INCRON_H_
#define _INCRON_H_

/// Common application name
#define INCRON_NAME "incron"

/// Daemon name
#define INCROND_NAME "incrond"

/// Table manipulator name
#define INCRONTAB_NAME "incrontab"

/// Application version (release)
#define INCRON_VERSION "0.5.12"

/// Default configuration file
#define INCRON_CONFIG "/etc/incron.conf"


#endif //_INCRON_H_
